/***************************************************************************
 *   Copyright (C) 2006 by Jean-Louis Fuchs                                 *
 *   ganwell@fangorn.ch                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef GETBRANCHLOG_H
#define GETBRANCHLOG_H

#include "Ancestors.h"
#include "Select.h"
#include "Toposort.h"

#include <QSet>
#include <QBrush>

class GetBranchLog : public QAbstractItemModel, public AutomateCommand
{
    Q_OBJECT
public:
    GetBranchLog(QObject *, const DatabaseFile &);
    ~GetBranchLog();

    // needed Qt Model methods
    QVariant data(const QModelIndex &, int) const;
    Qt::ItemFlags flags(const QModelIndex &) const;
    QVariant headerData(int, Qt::Orientation, int) const;
    QModelIndex index(int, int, const QModelIndex &) const;
    QModelIndex parent(const QModelIndex &) const;
    int rowCount(const QModelIndex &) const;
    int columnCount(const QModelIndex &) const;

    static const int PortionSize;

public slots:
    void readMore(const QString & branch = QString(), int revCount = PortionSize);
    void readAll(const QString & branch = QString());
    void stopReading();

signals:
    void readingStopped();

private:
    DatabaseFile databaseFile;
    QMap<QString, QStringList> revisionMap;
    QMap<QString, CertList> certMap;
    QMap<QString, QList<QString> > nextRevs;
    QSet<QString> mergeRevs;
    QString currentBranch;

    QBrush mergeRevsBrush;
    QBrush outOfBranchRevsBrush;

    int revsRead;
    int revsToRead;

    void readNext();
    void processTaskResult(const MonotoneTaskPtr &);
};

#endif

