/***************************************************************************
 *   Copyright (C) 2007 by Thomas Keller                                   *
 *   me@thomaskeller.biz                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef MONOTONE_UTIL_H
#define MONOTONE_UTIL_H

#include "vocab.h"
#include "MonotoneThread.h"

#include <QEventLoop>

class MonotoneUtil : public QObject
{
    Q_OBJECT
public:
    static void runSynchronousWorkspaceTask(const WorkspacePath &, const MonotoneTaskPtr &);
    static void runSynchronousDatabaseTask(const DatabaseFile &, const MonotoneTaskPtr &);
    static DatabaseFile getDatabaseFile(const WorkspacePath &);
    static QString getBaseWorkspaceRevision(const WorkspacePath &);
    static QString getOption(const WorkspacePath &, const QString &);
    static QString getBranchName(const WorkspacePath &, const QString & defaultBranch = tr("[unknown branch]"));
    static QString getBranchNameShort(const WorkspacePath &);
    static QStringList resolveSelector(const DatabaseFile &, const QString &);
    static CertList getCerts(const DatabaseFile &, const QString &);
    static FileEntryList getRevisionManifest(const DatabaseFile &, const QString &);
    static QMap<QString, QString> getPublicKeyMap(const DatabaseFile &);
    static QMap<QString, QString> getPrivateKeyMap(const DatabaseFile &);
    static QStringList getPreviousContentMarks(const DatabaseFile &, const QString &, const QString &);
    static QString getCorrespondingPath(const DatabaseFile &, const QString &, const QString &, const QString &);
    static QString getFileId(const DatabaseFile &, const QString &);
    static QStringList getRoots(const DatabaseFile &, bool &);
    static QStringList topsortRevisions(const DatabaseFile &, const QStringList &);
    static QStringList getCommonAncestors(const DatabaseFile &, const QStringList &);
    static bool getAttribute(const WorkspacePath &, const QString &, const QString &, QPair<QString, QString> &);
    static bool getAttribute(const DatabaseFile &, const QString &, const QString &, const QString &, QString &);
    static QMap<QString, QString> getDatabaseVariables(const DatabaseFile &, const QString &);

    // FIXME: decide what to do with that
    static QString stripMtnPrefix(const QString &);

signals:
    void finished();

private:
    void run(const MonotoneThreadPtr &, const MonotoneTaskPtr &);
    int currentCommandNumber;

private slots:
    void taskFinished(const MonotoneTaskPtr &);
    void taskAborted(const MonotoneTaskPtr &);
};

#endif
