/***************************************************************************
 *   Copyright (C) 2010 by Thomas Keller                                   *
 *   me@thomaskeller.biz                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "CertListBrowser.h"
#include "MonotoneUtil.h"

CertListBrowser::CertListBrowser(QWidget * parent)
  : QTextBrowser(parent) {}

CertListBrowser::~CertListBrowser() {}

void CertListBrowser::setKeyMap(const QMap<QString, QString> & map)
{
    keyMap = map;
}

void CertListBrowser::setCertList(const CertList & list)
{
    QString html =
        "<style type=\"text/css\">"
        "h1 { font-size: large; text-decoration: underline; }"
        "dl dt { font-weight: bold; }"
        "</style>"
    ;

    QStringList signers = list.signers();

    foreach (const QString & signer, signers)
    {
        QString certHtml, signerHtml;

        if (keyMap.contains(signer))
            signerHtml = tr("<h1>Signer: %1</h1>").arg(keyMap.value(signer));
        else
            signerHtml = tr("<h1>Signer: %1</h1>").arg(signer);

        foreach (const Cert & cert, list.findBySigner(signer))
        {
            QString name, value;
            if (cert.name == "date")
            {
                name = tr("Date");
                value = cert.dateTimeValue().toString(
                    Qt::DefaultLocaleShortDate
                );
            }
            else if (cert.name == "changelog")
            {
                name = tr("Changelog");
                value = cert.htmlValue();
            }
            else
            {
                // localize common certs
                if (cert.name == "author")
                    name = tr("Author");
                else if (cert.name == "branch")
                    name = tr("Branch");
                else if (cert.name == "tag")
                    name = tr("Tag");
                else
                    name = cert.name;

                value = cert.value;
            }

            certHtml += QString("<dt>%1</dt><dd>%2</dd>").arg(name).arg(value);
        }

        html += QString("%1<dl>%2</dl>").arg(signerHtml).arg(certHtml);
    }

    setHtml(html);
}

